DSTransaction class abstract

Represents a database transaction

Constructors

DSTransaction()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

commit() → Future<void>
Commits the transaction
createDocument(String collection, Map<String, dynamic> data) → Future<String>
Creates a document within this transaction
deleteDocument(String collection, String id) → Future<void>
Deletes a document within this transaction
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readDocument(String collection, String id) → Future<Map<String, dynamic>?>
Reads a document within this transaction
rollback() → Future<void>
Rolls back the transaction
toString() → String
A string representation of this object.
inherited
updateDocument(String collection, String id, Map<String, dynamic> data) → Future<void>
Updates a document within this transaction

Operators

operator ==(Object other) → bool
The equality operator.
inherited